# Benchmarks

We use Airspeed Velocity (*asv*) to benchmark locan.

In order to use *asv* look up the details in the [ASV documentation](https://asv.readthedocs.io/), or install *asv* and check `asv --help` and `asv run --help`.

